OpenCL

1 program Added 2025-10-29T12:14:39Z Model: x-ai/grok-4-fastTemp: 0.4 Evidence Report issue View issues
Aliases: OpenCL C
Provenance: commit 67fee24a4b · authored 2025-10-29T13:14:39+01:00 · model x-ai/grok-4-fast

Sources mentioning this language

7 sources · pl_id: pl/opencl
LLM (this repo) · 1PldbLinguistPygmentsWikipediaHyperpolyglotWikidata · Q681360

Wikipedia infobox

Pulled from the wikimedia/structured-wikipedia snapshot — see data/raw/wikipedia_pl_facts.*.jsonl and pl_fact.csv for the long-table provenance.

Paradigmsimperative (procedural) · structured · object-oriented · generic
Typingstatic, weak, manifest, nominal
Designed byKhronos Group
First appeared2009
Influenced byC99 · CUDA
LicenseOpenCL specification license
Homepagehttps://www.khronos.org/opencl

Extensions claimed by this language

9 claims. Each row is one upstream assertion with its strength. SWH column shows file occurrences with that extension across the entire archive.
ExtensionSourceStrengthSWH
.cllinguistprimary498.5K files
.propygmentsprimary3.4M files
.clpygmentssecondary498.5K files
.ipygmentssecondary8.8M files
.opencllinguistsecondary1.9K files
.packpygmentssecondary1.4M files
.phpygmentssecondary57.7K files
.clwikipediaproposed498.5K files
.clcppwikipediaproposed439 files

Related languages

OpenCL C (0.69)OpenACC (0.33)OpenABL (0.25)OpenCOBOL (0.24)OpenCilk (0.24)

LLM-contributed programs

SAXPY kernel

Provenance: commit 67fee24a4b · authored 2025-10-29T13:14:39+01:00 · model x-ai/grok-4-fast · Temp 0.4
code.cl · added: 2025-10-29T12:14:39Z
// OpenCL kernel code
__kernel void saxpy( __global float *restrict output,
                    __global const float *restrict input,
                    const float a,
                    const int n)
{
    // Get our index in the array
    unsigned int i = get_global_id(0);

    // Check array boundary
    if(i < n)
        output[i] = a * input[i] + output[i];
}

Real programs from Software Heritage

1 sample mined from derived_datasets/<date>/contents/*.parquet, byte-verified against the SWH archive. Citation-grade qualified SWHIDs preserved.
ubiq.pro · 50 B · ext .pro · seen 3376× in SWH
via fallback
swh:1:cnt:88fa153a6ccb3529f980494c6fd1241787dd41a7;origin=https://github.com/timbog/GreatGunGame;anchor=swh:1:rev:2c6b7799780573ef06376775de9d8de37d1888ba;path=/my_qreal_project/qreal-master/plugins/ubiq.pro
Open in SWH · Raw bytes (SWH) · GitHub raw
Show source
TEMPLATE = subdirs

SUBDIRS = \
	ubiq/ubiq.pro \

Disambiguation rules

Linguist heuristic rules that predict this language when one of its claimed extensions is shared with another.
RuleExtKindPredicates (truncated)
h/linguist/.cl/2.clpredicates[{"kind": "any", "regexes": ["\\/\\* |\\/\\/ |^\\}"]}]

Contribute — propose a file extension

Tell us where to find evidence about OpenCL (mapped to pl/opencl). A reference URL is required; at least one of extension or program code must be provided too. A maintainer reviews each submission via a draft PR before anything lands.
Optional: attach a program from that URL
If the reference URL points at a single source file you'd like to add as an example program, paste it below. The workflow will write it under languages/OpenCL/programs/<sha>/. Keep under ~200 lines.
(or open the pre-filled issue directly)
← OpenCilk OpenCL C →